@@ -1,19 +1,15 @@
 from .observable import Observable
-from collections import namedtuple
-
 
 class ObservableDict(dict, Observable):
-    _itemTuple = namedtuple('item', 'key value')
-    _itemChangedTuple = namedtuple('item', 'key value oldValue')
 
     def __init__(self, *args, **kwargs):
         Observable.__init__(self)
         dict.__init__(self, *args, **kwargs)
 
     def popitem(self):
-        keyValue = dict.popitem(self)
-        self.notify_observers(action="popitem", key=keyValue[0], item=keyValue[1])
-        return keyValue
+        key_value = dict.popitem(self)
+        self.notify_observers(action="popitem", key=key_value[0], item=key_value[1])
+        return key_value
 
     def pop(self, key, default=None):
         value = dict.pop(self, key, default)
@@ -29,7 +25,7 @@ class ObservableDict(dict, Observable):
         dict.__delitem__(self, key)
         self.notify_observers(action="delitem", key=key, item=value)
 
-    def update(self, dict2):
+    def update(self, dict2, **kwargs):
         items = []
         for key, value in dict2.items():
             items.append([key, value])
@@ -39,10 +35,3 @@ class ObservableDict(dict, Observable):
     def clear(self):
         dict.clear(self)
         self.notify_observers(action="clear")
-
-    def _createItemTuple(self, key, value, oldValue=None):
-        if oldValue is None:
-            item = self._itemTuple(key=key, value=value)
-        else:
-            item = self._itemChangedTuple(key=key, value=value, oldValue=oldValue)
-        return item
